@@ -73,7 +73,6 @@ class Socket(object):
                                     self.sid, transport)
             return getattr(self, '_upgrade_' + transport)(environ,
                                                           start_response)
-        self.connected = True
         try:
             packets = self.poll()
         except IOError as e:
@@ -137,6 +136,7 @@ class Socket(object):
                 return
         else:
             self.connected = True
+            self.upgraded = True
 
         def writer():
             while True:
@@ -150,8 +150,7 @@ class Socket(object):
                 except:
                     break
 
-        writer_task = getattr(self.server.async['threading'],
-                              self.server.async['thread_class'])(target=writer)
+        writer_task = self.server._start_background_task(writer)
         writer_task.start()
 
         self.server.logger.info(
